==> nextcloud-22.2.9.tgz: nextcloud/apps/text/l10n/zh_HK.js <==
OC.L10N.register(
    "text",
    {
    "New text file" : "新文字檔",
    "The file was uploaded" : "檔案已上傳",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "上傳的檔案大小超過 php.ini 當中 upload_max_filesize 選項的限制",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "上傳的檔案大小超過 HTML 表單中 MAX_FILE_SIZE 的限制",
    "The file was only partially uploaded" : "檔案僅部分上傳",
    "No file was uploaded" : "沒有檔案被上傳",
    "Missing a temporary folder" : "找不到暫存資料夾",
    "Could not write file to disk" : "寫入硬碟失敗",
    "A PHP extension stopped the file upload" : "某個 PHP 擴充功能終止檔案的上傳",
    "No file uploaded or file size exceeds maximum of %s" : "沒有上傳檔案或檔案大小超過 %s 的最大值",
    "Nextcloud Text" : "Nextcloud 文字編輯器",
    "text document" : "文字文件",
    "Readme" : "說明",
    "Text" : "文字編輯器",
    "📝 Collaborative document editing" : "📝 協作文件編輯",
    "** 📝 Collaborative document editing!**\n\n- **📝 Focused writing:** No distractions, only the formatting you need.\n- **🙋 Work together:** Share and collaborate with friends and colleagues, no matter if they use Nextcloud or not!\n- **💾 Open format:** Files are saved as [Markdown](https://en.wikipedia.org/wiki/Markdown), so you can edit them from any other text app too.\n- **✊ Strong foundation:** We use [🐈 tiptap](https://tiptap.scrumpy.io) which is based on [🦉 ProseMirror](https://prosemirror.net) – huge thanks to them!" : "** 📝 協作文件編輯！**\n\n- **📝 聚焦編輯：** 沒有不重要的東西，只有你需要的格式化。\n- **🙋 共同作業：** 與朋友及同事協作，無關他們是否使用 Nextcloud！\n- **💾 開放格式：** 檔案會以 [Markdown]（https://en.wikipedia.org/wiki/Markdown）儲存，所以你也能在其他文字編輯器編輯。\n- **✊ 強大基礎：** 我們使用基於 [🦉 ProseMirror]（https://prosemirror.net）的 [🐈 tiptap]（https://tiptap.scrumpy.io）– 超級感謝他們！",
    "Use current version" : "使用目前版本",
    "Use the saved version" : "使用儲存版本",
    "Image file format not supported" : "不支持圖像格式",
    "Insert an image" : "插入圖像",
    "Document idle for {timeout} minutes, click to continue editing" : "文件已閒置 {timeout} 分鐘。點選以繼續編輯",
    "Reconnect" : "重新連接",
    "The document has been changed outside of the editor. The changes cannot be applied." : "文件已在編輯器外變更。變更無法套用。",
    "File could not be loaded. Please check your internet connection." : "無法載入檔案。請檢查您的網路連線。",
    "This file is opened read-only as it is currently locked by {user}." : "此檔案以唯讀模式打開，因為它當前被 {user} 鎖上。",
    "Saving …" : "正在儲存……",
    "Saved" : "已儲存",
    "Last saved {lastSaved}" : "上次儲存於 {lastSaved}",
    "Unsaved changes" : "未儲存變更",
    "No emoji found" : "找不到表情符號",
    "Enter your name so other people can see who is editing" : "輸入您的姓名，以便其他人可以看到誰在編輯",
    "Edit guest name" : "編輯訪客名稱",
    "Guest" : "訪客",
    "Save guest name" : "儲存訪客名稱",
    "Formatting help" : "格式化說明",
    "Speed up your writing with simple shortcuts." : "使用簡單的快捷方式加快您的寫作速度。",
    "Just type the Markdown syntax or use keyboard shortcuts from below." : "只需輸入 Markdown 語法或使用下方的鍵盤快捷鍵即可。",
    "Just type the Markdown syntax from below." : "只需輸入下方的 Markdown 語法即可。",
    "Style" : "樣式",
    "Syntax" : "語法",
    "Keyboard shortcuts" : "鍵盤快捷鍵",
    "Bold" : "粗體",
    "Bold text" : "粗體文字",
    "Ctrl" : "Ctrl",
    "Italic" : "斜體",
    "Italicized text" : "斜體文字",
    "Strikethrough" : "刪除線",
    "Mistaken text" : "錯誤的文字",
    "Shift" : "轉移",
    "Underline" : "下面畫線",
    "Underlined text" : "下面畫線的文字",
    "Heading 1" : "標題 1",
    "Heading level 1" : "標題級別 1",
    "Heading 6" : "標題 6",
    "Heading level 6" : "標題級別 6",
    "Unordered list" : "無序清單",
    "An item" : "一個項目",
    "Ordered list" : "有序清單",
    "First item" : "第一個項目",
    "Checklist" : "清單",
    "Todo item" : "待辦事項",
    "Blockquote" : "引文",
    "Quoted text" : "引用文字",
    "Code block" : "程式碼區塊",
    "Some code" : "一些代碼",
    "Upload from computer" : "從電腦上傳",
    "Insert from Files" : "從檔案插入",
    "Remaining Actions" : "剩餘操作",
    "Update Link" : "更新連結",
    "Add Link" : "添加連結",
    "Link file" : "連結檔案",
    "Remove Link" : "移除連結",
    "Select file to link to" : "選擇要連結的檔案",
    "Active people" : "活躍的人",
    "guest" : "訪客",
    "Show author colors" : "顯示作者顏色",
    "Author colors are only shown until everyone has closed the document." : "僅在所有人都關閉文件前才顯示文件顏色。",
    "Failed to load" : "加載失敗",
    "Unsuported image" : "不支援的圖像類型",
    "Add row before" : "在前面添加行",
    "Add row after" : "在後面添加行",
    "Delete this row" : "刪除此行",
    "Add column before" : "在前面添加縱列",
    "Add column after" : "在後面添加縱列",
    "Delete this column" : "删除此縱列",
    "Delete this table" : "删除此表",
    "Show rich workspaces" : "顯示較多功能的工作區",
    "Add notes, lists or links …" : "加入筆記、清單或連結…",
    "Undo" : "復原",
    "Redo" : "重作",
    "Headings" : "標題",
    "Heading 2" : "標題 2",
    "Heading 3" : "標題 3",
    "Heading 4" : "標題 4",
    "Heading 5" : "標題 5",
    "ToDo list" : "待辦清單",
    "Callouts" : "標記",
    "Info" : "資訊",
    "Success" : "成功",
    "Warning" : "警告",
    "Danger" : "危險",
    "Table" : "表",
    "Insert emoji" : "插入 emoji",
    "Insert image" : "插入圖像",
    "Alt" : "Alt",
    "Edit" : "編輯",
    "New text document" : "新文字文件",
    "Enter your name so other users can see who is editing" : "輸入您的名稱，這樣其他用戶才能查看是誰在編輯",
    "Currently active users:" : "目前活躍用戶：",
    "_and %n other editor_::_and %n other editors_" : ["及其他 %n 個編輯"],
    "Emoji picker" : "Emoji 選擇器",
    "Participants" : "參與者"
},
"nplurals=1; plural=0;");

==> nextcloud-23.0.3.tgz: nextcloud/apps/text/l10n/zh_HK.js <==
OC.L10N.register(
    "text",
    {
    "New text document" : "新文字文件",
    "The file was uploaded" : "檔案已上傳",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "上傳的檔案大小超過 php.ini 當中 upload_max_filesize 選項的限制",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "上傳的檔案大小超過 HTML 表單中 MAX_FILE_SIZE 的限制",
    "The file was only partially uploaded" : "檔案僅部分上傳",
    "No file was uploaded" : "沒有檔案被上傳",
    "Missing a temporary folder" : "找不到暫存資料夾",
    "Could not write file to disk" : "寫入硬碟失敗",
    "A PHP extension stopped the file upload" : "某個 PHP 擴充功能終止檔案的上傳",
    "No file uploaded or file size exceeds maximum of %s" : "沒有上傳檔案或檔案大小超過 %s 的最大值",
    "Nextcloud Text" : "Nextcloud 文字編輯器",
    "text document" : "文字文件",
    "Readme" : "說明",
    "Text" : "文字編輯器",
    "📝 Collaborative document editing" : "📝 協作文件編輯",
    "** 📝 Collaborative document editing!**\n\n- **📝 Focused writing:** No distractions, only the formatting you need.\n- **🙋 Work together:** Share and collaborate with friends and colleagues, no matter if they use Nextcloud or not!\n- **💾 Open format:** Files are saved as [Markdown](https://en.wikipedia.org/wiki/Markdown), so you can edit them from any other text app too.\n- **✊ Strong foundation:** We use [🐈 tiptap](https://tiptap.scrumpy.io) which is based on [🦉 ProseMirror](https://prosemirror.net) – huge thanks to them!" : "** 📝 協作文件編輯！**\n\n- **📝 聚焦編輯：** 沒有不重要的東西，只有你需要的格式化。\n- **🙋 共同作業：** 與朋友及同事協作，無關他們是否使用 Nextcloud！\n- **💾 開放格式：** 檔案會以 [Markdown]（https://en.wikipedia.org/wiki/Markdown）儲存，所以你也能在其他文字編輯器編輯。\n- **✊ 強大基礎：** 我們使用基於 [🦉 ProseMirror]（https://prosemirror.net）的 [🐈 tiptap]（https://tiptap.scrumpy.io）– 超級感謝他們！",
    "Use current version" : "使用目前版本",
    "Use the saved version" : "使用儲存版本",
    "Document idle for {timeout} minutes, click to continue editing" : "文件已閒置 {timeout} 分鐘。點選以繼續編輯",
    "Reconnect" : "重新連接",
    "The document has been changed outside of the editor. The changes cannot be applied." : "文件已在編輯器外變更。變更無法套用。",
    "File could not be loaded. Please check your internet connection." : "無法載入檔案。請檢查您的網路連線。",
    "Saving …" : "正在儲存……",
    "Saved" : "已儲存",
    "Last saved {lastSaved}" : "上次儲存於 {lastSaved}",
    "Unsaved changes" : "未儲存變更",
    "No emoji found" : "找不到表情符號",
    "Enter your name so other users can see who is editing" : "輸入您的名稱，這樣其他用戶才能查看是誰在編輯",
    "Edit guest name" : "編輯訪客名稱",
    "Save guest name" : "儲存訪客名稱",
    "Formatting help" : "格式化說明",
    "Speed up your writing with simple shortcuts." : "使用簡單的快捷方式加快您的寫作速度。",
    "Just type the Markdown syntax or use keyboard shortcuts from below." : "只需輸入 Markdown 語法或使用下方的鍵盤快捷鍵即可。",
    "Just type the Markdown syntax from below." : "只需輸入下方的 Markdown 語法即可。",
    "Style" : "樣式",
    "Syntax" : "語法",
    "Keyboard shortcuts" : "鍵盤快捷鍵",
    "Bold" : "粗體",
    "Bold text" : "粗體文字",
    "Ctrl" : "Ctrl",
    "Italic" : "斜體",
    "Italicized text" : "斜體文字",
    "Strikethrough" : "刪除線",
    "Mistaken text" : "錯誤的文字",
    "Shift" : "轉移",
    "Underline" : "下面畫線",
    "Underlined text" : "下面畫線的文字",
    "Heading 1" : "標題 1",
    "Heading level 1" : "標題級別 1",
    "Heading 6" : "標題 6",
    "Heading level 6" : "標題級別 6",
    "Unordered list" : "無序清單",
    "An item" : "一個項目",
    "Ordered list" : "有序清單",
    "First item" : "第一個項目",
    "Checklist" : "清單",
    "Todo item" : "待辦事項",
    "Blockquote" : "引文",
    "Quoted text" : "引用文字",
    "Code block" : "程式碼區塊",
    "Some code" : "一些代碼",
    "Insert emoji" : "插入 emoji",
    "Upload from computer" : "從電腦上傳",
    "Insert from Files" : "從檔案插入",
    "Insert from link" : "從連結插入",
    "Image link to insert" : "要插入的圖像連結",
    "Insert image" : "插入圖像",
    "Image format not supported" : "不支持圖像格式",
    "Insert an image" : "插入圖像",
    "Alt" : "Alt",
    "Update Link" : "更新連結",
    "Add Link" : "添加連結",
    "Link file" : "連結檔案",
    "Remove Link" : "移除連結",
    "Select file to link to" : "選擇要連結的檔案",
    "Show author colors" : "顯示作者顏色",
    "Author colors are only shown until everyone has closed the document." : "僅在所有人都關閉文件前才顯示文件顏色。",
    "Currently active users:" : "目前活躍用戶：",
    "_and %n other editor_::_and %n other editors_" : ["及其他 %n 個編輯"],
    "Show rich workspaces" : "顯示較多功能的工作區",
    "Add notes, lists or links …" : "加入筆記、清單或連結…",
    "Edit" : "編輯",
    "Undo" : "復原",
    "Redo" : "重作",
    "Headings" : "標題",
    "Heading 2" : "標題 2",
    "Heading 3" : "標題 3",
    "Heading 4" : "標題 4",
    "Heading 5" : "標題 5",
    "ToDo list" : "待辦清單",
    "Callouts" : "標記",
    "Info" : "資訊",
    "Success" : "成功",
    "Warning" : "警告",
    "Danger" : "危險",
    "Emoji picker" : "Emoji 選擇器"
},
"nplurals=1; plural=0;");
